@@ -4,14 +4,12 @@ package DTest;
 use feature qw(:5.12);
 use strict;
 use warnings;
-use File::Spec;
 
 use parent 'Exporter';
 use Import::Into;
 
 use Test::More;
-#use IPC::Run3;
-#use Test::LongString;
+use Test::OnlySome::PathCapsule;
 use Carp qw(carp croak);
 use constant { true => !!1, false => !!0 };
 
@@ -73,17 +71,17 @@ sub tokencopy { # Return the string we expect as a copy of the input. {{{1
 
 sub localpath { # Return the path to a file in the same directory as the caller {{{1
     my $newfn = shift or croak 'Need a filename';
-
-    my ($package, $filename, $line) = caller;
+    my ($package, $filename) = caller;
 
     $filename = 'dummy' unless $filename && $filename ne '-e';
         # Dummy filename assumed to be in cwd, if we're running from -e
         # or are otherwise without a caller.
-    $filename = File::Spec->rel2abs($filename);
-        # Assume the code up to this point hasn't changed cwd
-    my $voldir = [File::Spec->splitpath($filename)];
 
-    return File::Spec->catpath($voldir->[0], $voldir->[1], $newfn)
+    my $path = Test::OnlySome::PathCapsule->new($filename);
+        # Assume the code up to this point hasn't changed cwd
+
+    $path->file($newfn);
+    return $path->abs;
 } #}}}1
 
 sub import { # {{{1
